#!/usr/bin/python
# -*- coding: utf-8 -*-
import osgeo.ogr as ogr
import osgeo.osr as osr
import numpy as np
import gdal
import sys

#-------------------------------------------------------------------------------

def replaceOclussions(filename1, filename2, outFilename):
	'''
		Fill File2 Clouds with File1 Data
	'''
	clouds = [0, 3,8,9,10]
	input1 = gdal.Open(filename1)
	rows1, cols1, geotransform1 = input1.RasterYSize, input1.RasterXSize, input1.GetGeoTransform()
	data1 = input1.GetRasterBand(1).ReadAsArray(0,0,cols1,rows1)

	input2 = gdal.Open(filename2)
	rows2, cols2, geotransform2 = input2.RasterYSize, input2.RasterXSize, input2.GetGeoTransform()
	data2 = input2.GetRasterBand(1).ReadAsArray(0,0,cols2,rows2)


	driverTiff = gdal.GetDriverByName('GTiff')
	output = driverTiff.Create(outFilename, cols2, rows2, 1, gdal.GDT_Byte)

	sr = osr.SpatialReference()
	sr.ImportFromWkt(input2.GetProjection())
	output.GetRasterBand(1).SetNoDataValue(-99)
	output.GetRasterBand(1).WriteArray(np.zeros((rows2, cols2)))
	output.GetRasterBand(1).FlushCache()
	output.SetGeoTransform(geotransform2)
	output.SetProjection(sr.ExportToWkt())

	for r in range(rows1):
		for c in range(cols1):
			if data2.item((r,c)) in clouds:
				data2.itemset( (r,c), data1.item((r,c)) )

	output.GetRasterBand(1).WriteArray(data2)
	output.GetRasterBand(1).FlushCache()

	input1 = None
	input2 = None
	output = None
#-------------------------------------------------------------------------------
def main(argv):
	if len(sys.argv) != 4:
		print("Usage: " + argv[0] + " <file1> <file2> <output>")
	else:
		replaceOclussions(argv[1], argv[2], argv[3])
#-------------------------------------------------------------------------------
if __name__ == "__main__":
	main(sys.argv)
