#!/usr/bin/python
# -*- coding: utf-8 -*-
#"POLYGON((-89.65513229370117 21.048938357786966,-89.62852478027342 21.047816903874505,-89.6261215209961 21.03339745836918,-89.6465492248535 21.022822311328852,-89.65873718261717 21.039325621609095,-89.65513229370117 21.048938357786966))"
import osgeo.ogr as ogr
import osgeo.osr as osr
import numpy as np
import gdal
import sys
#-------------------------------------------------------------------------------
def createLayer(wkt, layerName="wkt"):
	# create the spatial reference, WGS84
	srs = osr.SpatialReference()
	srs.ImportFromEPSG(4326)
	layer = data_source.CreateLayer(layerName, srs, ogr.wkbPolygon)

	# Create the point from the Well Known Text
	geometry = ogr.CreateGeometryFromWkt(wkt)
	# create the feature
	feature = ogr.Feature(layer.GetLayerDefn())
	# Set the feature geometry using the point
	feature.SetGeometry(geometry)
	# Create the feature in the layer (shapefile)
	layer.CreateFeature(feature)
	# Dereference the feature
	feature = None
	return layer
#-------------------------------------------------------------------------------
def getPolygonArray(image, wkt):
	rows, cols, geotransform = image.RasterYSize, image.RasterXSize, image.GetGeoTransform()
	print(rows, cols, geotransform)
	sr = osr.SpatialReference()
	sr.ImportFromWkt(image.GetProjection())

	driverTiff = gdal.GetDriverByName('GTiff')
	polygonRaster = driverTiff.Create("polygonTmp.tif", cols, rows, 1, gdal.GDT_Byte)

	#Set up polygon raster
	polygonRaster.GetRasterBand(1).SetNoDataValue(-99)
	polygonRaster.GetRasterBand(1).WriteArray(np.zeros((rows, cols)))
	polygonRaster.GetRasterBand(1).FlushCache()
	polygonRaster.SetGeoTransform(geotransform)
	polygonRaster.SetProjection(sr.ExportToWkt())

	# shapefile
	driverShp = ogr.GetDriverByName("ESRI Shapefile")
	data_source = driverShp.CreateDataSource("myShape.shp")

	#Burn Polygon
	srs = osr.SpatialReference()
	srs.ImportFromEPSG(4326)
	layer = data_source.CreateLayer("wkt", srs, ogr.wkbPolygon)
	geometry = ogr.CreateGeometryFromWkt(wkt)
	feature = ogr.Feature(layer.GetLayerDefn())

#	feature.SetStyleString("PEN(c:#FF0000,w:5px);")
	feature.SetGeometry(geometry)
	layer.CreateFeature(feature)

	gdal.RasterizeLayer(polygonRaster, [1], layer, burn_values=[255])
	polygonRaster.GetRasterBand(1).FlushCache()

	np_polygon = polygonRaster.GetRasterBand(1).ReadAsArray(0,0,cols,rows)

	feature = None
	data_source = None
	polygonRaster = None

	return np_polygon
#-------------------------------------------------------------------------------
def rasterWkt(wkt, inputfile, outputfile):
	''' 
	Draw WKT Polygon into a Image
	'''
	print (wkt)
	print (inputfile)
	print (outputfile)
	inputImage = gdal.Open(inputfile)
	rows, cols, geotransform = inputImage.RasterYSize, inputImage.RasterXSize, inputImage.GetGeoTransform()
	sr = osr.SpatialReference()
	sr.ImportFromWkt(inputImage.GetProjection())
	# Read the input bands as numpy arrays.

	print("driver")
	driverTiff = gdal.GetDriverByName('GTiff')
	output = driverTiff.Create(outputfile, cols, rows, inputImage.RasterCount, gdal.GDT_Byte)
	polygonRaster = driverTiff.Create("polygonTmp.tif", cols, rows, 1, gdal.GDT_Byte)


	#Set up polygon raster
	polygonRaster.GetRasterBand(1).SetNoDataValue(-99)
	polygonRaster.GetRasterBand(1).WriteArray(np.zeros((rows, cols)))
	polygonRaster.GetRasterBand(1).FlushCache()
	polygonRaster.SetGeoTransform(geotransform)
	polygonRaster.SetGeoTransform(geotransform)
	polygonRaster.SetProjection(sr.ExportToWkt())


	print("Shapefile")
	# shapefile
	driver = ogr.GetDriverByName("ESRI Shapefile")
	data_source = driver.CreateDataSource("myShape.shp")


	print("Burn Polygon")
	#Burn Polygon
	srs = osr.SpatialReference()
	srs.ImportFromEPSG(4326)
	layer = data_source.GetLayer()
#	layer = data_source.CreateLayer("wkt", srs, ogr.wkbPolygon)
#	geometry = ogr.CreateGeometryFromWkt(wkt)
#	feature = ogr.Feature(layer.GetLayerDefn())

	print("features")
#	feature.SetStyleString("PEN(c:#FF0000,w:5px);")
#	feature.SetGeometry(geometry)
#	layer.CreateFeature(feature)

	gdal.RasterizeLayer(polygonRaster, [1], layer, burn_values=[255])
	polygonRaster.GetRasterBand(1).FlushCache()

#	Draw output image
	np_polygon = polygonRaster.GetRasterBand(1).ReadAsArray(0,0,cols,rows)
#	np_polygon = getPolygonArray(inputImage, wkt)
	print("Setup")
	for b in range(1, output.RasterCount+1):
		np_input = np_polygon & inputImage.GetRasterBand(b).ReadAsArray(0,0,cols,rows)
		output.GetRasterBand(b).SetNoDataValue(-99)
		output.GetRasterBand(b).WriteArray(np_input)
		output.GetRasterBand(b).FlushCache()

	output.SetGeoTransform(geotransform)
	output.SetProjection(sr.ExportToWkt())

	print("end")
	#Close files
#	feature = None
#	data_source = None
#	polygonRaster = None
	output = None
	inputImage = None

def main(argv):
	rasterWkt(argv[1], argv[2], argv[3])

if __name__ == "__main__":
	main(sys.argv)
